@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2009, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2009, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -52,7 +52,7 @@
 #include "objimpl/db.query/db_query_QueryBuffer.h"
 #include "grts/structs.db.query.h"
 
-#include "grtdb/db_object_helpers.h"
+#include "grtdb/db_helpers.h"
 
 #include "mforms/code_editor.h"
 #include "mforms/menubar.h"
@@ -103,7 +103,7 @@ class MYSQLWBBACKEND_PUBLIC_FUNC db_query_EditorConcreteImplData : public db_que
       }
       else
       {
-        log_warning("recordset_list_changed received for invalid editor index (%i). Internal state of db_query_QueryEditor might have become inconsistent",
+        log_warning("recordset_list_changed received for invalid editor index (%i). Internal state of db_query_QueryEditor might have become inconsistent\n",
                     editor_index);
         return;
       }
@@ -669,7 +669,7 @@ bool WBContextSQLIDE::auto_save_workspaces()
     }
     catch (const std::exception &exception)
     {
-      g_warning("Exception during auto-save of SQL Editors: %s", exception.what());
+      log_warning("Exception during auto-save of SQL Editors: %s\n", exception.what());
       wb->get_grt_manager()->replace_status_text(base::strfmt("Error during auto-save of SQL Editors: %s", exception.what()));
     }
   }
@@ -800,6 +800,7 @@ void WBContextSQLIDE::init()
   cmdui->add_builtin_command("query.explain_current_statement",
                                                boost::bind(&WBContextSQLIDE::call_in_editor, this, &SqlEditorForm::explain_current_statement));
 
+  cmdui->add_builtin_command("query.jump_to_placeholder", boost::bind(&WBContextSQLIDE::call_in_editor, this, &SqlEditorForm::jump_to_placeholder));
   cmdui->add_builtin_command("list-members", boost::bind(&WBContextSQLIDE::call_in_editor, this, &SqlEditorForm::list_members),
                              boost::bind(validate_list_members, this));
 }
@@ -958,10 +959,7 @@ SqlEditorForm::Ref WBContextSQLIDE::create_connected_editor(const db_mgmt_Connec
       std::time_t time = std::time(0);
       parameter_values.gset("lastConnected", (long)time);
 
-      GrtVersionRef version = CatalogHelper::parse_version(object.get_grt(), details["dbmsProductVersion"]);
-      version->owner(object);
-      version->name(grt::StringRef(details["dbmsProductName"]));
-      object->serverVersion(version);
+      object->serverVersion(editor->rdbms_version());
     }
 
     _wbui->get_wb()->get_root()->sqlEditors().insert(object);
