@@ -205,13 +205,20 @@ namespace MySQL.GUI.Workbench
                 RemoveViewFromResultTabview(editor, resultTabPage.Tag as AppViewImpl);
             }
           }
+
+          // Free only our managed resources attached to that editor but leave all
+          // the backend structures intact (and hence our maps too), so the backend
+          // can properly process the editors on close (e.g. auto save).
+          // The backend resources will then be freed by the backend.
+          editor.Dispose();
+          continue;
         }
 
         // AppView still does not support can_close/close duality.
         if (page.Tag is AppViewImpl)
           (page.Tag as AppViewImpl).DocumentClosing();
         else
-          closeEditorTab(page, true);
+          closeEditorTab(page); // Non-editor tabs.
       }
 
       historyDetailsView.Dispose();
@@ -613,7 +620,12 @@ namespace MySQL.GUI.Workbench
       Logger.LogDebug("WQE.net", 1, "Can close tab: " + e.canClose + "\n");
     }
 
-    private void closeEditorTab(TabPage page, bool disposing = false)
+    /// <summary>
+    /// Removes a tab page docked to the editor tab control (code editors, object editors etc.)
+    /// This routine must not called for code editors on dispose.
+    /// </summary>
+    /// <param name="page"></param>
+    private void closeEditorTab(TabPage page)
     {
       Logger.LogDebug("WQE.net", 1, "Closing tab: " + page.Text + "\n");
       int editorIndex = EditorIndexFromTabPage(page);
@@ -621,29 +633,24 @@ namespace MySQL.GUI.Workbench
       {
         RemoveSqlEditor(editorIndex);
 
-        // If the last editor was closed create a new, empty one.
-        // But not when we are shutting down.
-        if (!disposing)
+        if (sqlEditors.Count > 0)
         {
-          if (sqlEditors.Count > 0)
+          editorIndex = EditorIndexFromTabIndex(mainContentTabControl.SelectedIndex);
+          if (editorIndex > -1)
           {
-            editorIndex = EditorIndexFromTabIndex(mainContentTabControl.SelectedIndex);
-            if (editorIndex > -1)
-            {
-              Logger.LogDebug("WQE.net", 2, "Activating editor at index: " + editorIndex + "\n");
-              dbSqlEditorBE.active_sql_editor_index(editorIndex);
-            }
-          }
-          else
-          {
-            Logger.LogDebug("WQE.net", 2, "All editors closed. Create a new script tab\n");
-            dbSqlEditorBE.new_sql_script_file(); // This will call our callback for setting up the editor.
-            dbSqlEditorBE.active_sql_editor_index(0);
-            SqlEditorWrapper sqlEditor = ActiveEditor;
-            if (sqlEditor != null)
-              ActiveControl = sqlEditor.get_editor_container();
+            Logger.LogDebug("WQE.net", 2, "Activating editor at index: " + editorIndex + "\n");
+            dbSqlEditorBE.active_sql_editor_index(editorIndex);
           }
         }
+        else
+        {
+          Logger.LogDebug("WQE.net", 2, "All editors closed. Create a new script tab\n");
+          dbSqlEditorBE.new_sql_script_file(); // This will call our callback for setting up the editor.
+          dbSqlEditorBE.active_sql_editor_index(0);
+          SqlEditorWrapper sqlEditor = ActiveEditor;
+          if (sqlEditor != null)
+            ActiveControl = sqlEditor.get_editor_container();
+        }
       }
       else
       {
