@@ -1,5 +1,5 @@
 /* 
- * Copyright (c) 2008, 2013, Oracle and/or its affiliates. All rights reserved.
+ * Copyright (c) 2008, 2014, Oracle and/or its affiliates. All rights reserved.
  *
  * This program is free software; you can redistribute it and/or
  * modify it under the terms of the GNU General Public License as
@@ -524,8 +524,12 @@ void ViewImpl::focus(mforms::View *self)
   if (view != nullptr)
   {
     Control^ control = view->get_control();
-    if (control->CanFocus)
-      control->Focus();
+    Windows::Forms::Form ^form = control->FindForm();
+    if (form != nullptr)
+      form->ActiveControl = control;
+    else
+      if (control->CanSelect)
+        control->Select();
   }
 }
 
@@ -663,10 +667,22 @@ String^ ViewImpl::get_front_color()
 
 void ViewImpl::set_back_color(String ^color)
 {
+  Control ^control = get_control<Control>();
   if (color == "")
-    get_control<Control>()->BackColor = Color::Transparent;
+  {
+    // Use an empty string as indicator to reset the background color.
+    control->ResetBackColor();
+    if (is<TreeViewAdv>(control))
+      control->BackColor = SystemColors::Window;
+    else
+      if (is<ButtonBase>(control))
+        ((ButtonBase ^)control)->UseVisualStyleBackColor = true;
+      else
+        if (is<TabPage>(control))
+          ((TabPage ^)control)->UseVisualStyleBackColor = true;
+  }
   else
-    get_control<Control>()->BackColor = System::Drawing::ColorTranslator::FromHtml(color);
+    control->BackColor = System::Drawing::ColorTranslator::FromHtml(color);
 }
 
 //-------------------------------------------------------------------------------------------------
@@ -789,7 +805,7 @@ void ViewImpl::Resize(System::Object ^sender, EventArgs ^e)
   {
     mforms::View* view = ViewImpl::get_backend_control<mforms::View>(control);
     if (!view->is_destroying())
-      (*view->signal_resized())();
+      view->resize();
   }
 }
 
