@@ -24,6 +24,7 @@
 #include "module_db_mysql.h"
 
 #include "changelistobjects.h"
+#include "grtdb/db_helpers.h"
 
 using namespace std;
 using namespace tut;
@@ -53,12 +54,12 @@ protected:
       ensure("DiffSQLGen module initialization", NULL != diffsql_module);
 
       // init datatypes
-      populate_grt(tester.grt, NULL, tester);
+      populate_grt(tester.grt, tester);
 
       std::string target_version = tester.wb->get_grt_manager()->get_app_option_string("DefaultTargetMySQLVersion");
       if (target_version.empty())
         target_version = "5.5";
-      tester.get_rdbms()->version(CatalogHelper::parse_version(tester.grt, target_version));
+      tester.get_rdbms()->version(parse_version(tester.grt, target_version));
 
       // init database connection
       connection= tester.create_connection_for_import();
@@ -66,8 +67,16 @@ protected:
       sql_parser= SqlFacade::instance_for_rdbms_name(tester.grt, "Mysql");
       ensure("failed to get sqlparser module", (NULL != sql_parser));
   }
+  
+  TEST_DATA_DESTRUCTOR(grtdiff_alter_test)
+  {
+    std::auto_ptr<sql::Statement> stmt(connection->createStatement());
+    std::string sql_string = "DROP DATABASE IF EXISTS grtdiff_alter_test;";
+    
+    execute_script(stmt.get(), sql_string, tester.wb->get_grt_manager());
+  }
 
-  END_TEST_DATA_CLASS
+END_TEST_DATA_CLASS
 
 TEST_MODULE(grtdiff_alter_test, "GRT: diff alter");
 
@@ -1421,25 +1430,26 @@ TEST_FUNCTION(7)
     alter_change->dump_log(0);
 #endif
 
-	const char TemplateFile[] = //"E:\\projects\\mysql\\WB 5.1\\workbench\\testing\\tut\\"
-		"data\\reporting\\Basic_Text.tpl\\basic_text_report.txt.tpl";
+    const char TemplateFile[] = "data/reporting/Basic_Text.tpl/basic_text_report.txt.tpl";
+
     // 1. generate alter
     grt::StringListRef alter_map(tester.grt);
     grt::DictRef options(tester.grt);
     options.set("UseFilteredLists", grt::IntegerRef(0));
     options.set("OutputContainer", alter_map);
-	options.set("TemplateFile", grt::StringRef(TemplateFile));
-	options.set("UseShortNames", grt::IntegerRef(j));
-  options.set("SeparateForeignKeys", grt::IntegerRef(0));
-
-    
-	grt::StringRef report = diffsql_module->generateReport(org_cat, options, alter_change);
+    options.set("TemplateFile", grt::StringRef(TemplateFile));
+    options.set("UseShortNames", grt::IntegerRef(j));
+    options.set("SeparateForeignKeys", grt::IntegerRef(0));
+ 
+    grt::StringRef report = diffsql_module->generateReport(org_cat, options, alter_change);
 
     char buf1[1000];
-	g_snprintf(buf1, sizeof(buf1), "data\\reporting\\Basic_Text.tpl\\reports\\testres%s%d.txt",j?"_longname":"_shortname", i);
-	std::ifstream rep;
-	rep.open(buf1);
-	std::string str((std::istreambuf_iterator<char>(rep)), std::istreambuf_iterator<char>());
+    
+    g_snprintf(buf1, sizeof(buf1), "data/reporting/Basic_Text.tpl/reports/testres%s%d.txt",j?"_longname":"_shortname", i);
+
+    std::ifstream rep;
+    rep.open(buf1);
+    std::string str((std::istreambuf_iterator<char>(rep)), std::istreambuf_iterator<char>());
 
     if (report != str)
     {
@@ -1620,3 +1630,4 @@ TEST_FUNCTION(5)
 
 
 END_TESTS
+
